Index: test/cctest/test-parsing.cc |
diff --git a/test/cctest/test-parsing.cc b/test/cctest/test-parsing.cc |
index 1b6e4ab9a15089a14edf578c2394af4e6728b866..cd8a6aff382934ae11c8ce45212e967f6c1fedd7 100755 |
--- a/test/cctest/test-parsing.cc |
+++ b/test/cctest/test-parsing.cc |
@@ -65,8 +65,9 @@ TEST(ScanKeywords) { |
{ |
i::Utf8ToUC16CharacterStream stream(keyword, length); |
i::Scanner scanner(&unicode_cache); |
// The scanner should parse 'let' as Token::LET for this test. |
scanner.SetHarmonyScoping(true); |
+ scanner.SetHarmonyModules(true); |
scanner.Initialize(&stream); |
CHECK_EQ(key_token.token, scanner.Next()); |
CHECK_EQ(i::Token::EOS, scanner.Next()); |
@@ -65,8 +65,9 @@ TEST(ScanKeywords) { |
i::Utf8ToUC16CharacterStream stream(keyword, length); |
i::Scanner scanner(&unicode_cache); |
- // The scanner should parse 'let' as Token::LET for this test. |
+ // The scanner should parse Harmony keywords for this test. |
scanner.SetHarmonyScoping(true); |